
.. [SRI2012] PyFAI, a versatile library for azimuthal regrouping
   J. Kieffer & D. Karkoulis
   J. Phys.: Conf. Ser. 425 202012
   http://dx.doi.org/10.1088/1742-6596/425/20/202012

.. [EPDIC13] PyFAI: a Python library for high performance azimuthal integration on GPU
   J. Kieffer & J. P. Wright,
   Powder Diffraction / Volume 28 / Supplement S2 / September 2013, pp S339-S350
   http://dx.doi.org/10.1017/S0885715613000924

.. [FIT2D] Hammersley A. P., Svensson S. O., Hanfland M., Fitch A. N. and Hausermann D.
   1996 High Press. Res. vol14 p235–248

.. [SPD] Bösecke P. 2007 J. Appl. Cryst. vol40 s423–s427

.. [EDNA] Incardona M. F., Bourenkov G. P., Levik K., Pieritz R. A., Popov A. N. and Svensson O.
   2009 J. Synchrotron Rad. vol16 p872–879

.. [PyMca] Solé V. A., Papillon E., Cotte M., Walter P. and Susini J.
   2007 Spectrochim. Acta Part B vol vol62 p63 – 68

.. [PyNX] Favre-Nicolin V., Coraux J., Richard M. I. and Renevier H.
   2011 J. Appl. Cryst. vol44 p635–640

.. [IPython] Pérez F and Granger B E
   2007 Comput. Sci. Eng. vol9 p21–29 URL http://ipython.org

.. [NumPy] Oliphant T E 2007 Comput. Sci. Eng. vol9 p10–20

.. [Cython] Behnel S, Bradshaw R, Citro C, Dalcin L, Seljebotn D and Smith K 2011 Comput. Sci. Eng. vol13 p31 –39

.. [OpenCL] Khronos OpenCL Working Group 2010 The OpenCL Specification, version 1.1 URL http://www.khronos.org/registry/cl/specs/opencl-1.1.pdf

.. [FabIO] Sorensen H O, Knudsen E, Wright J, Kieffer J et al.
   2007–2013 FabIO: I/O library for images produced by 2D X-ray detectors URL http://fable.sf.net/

.. [Matplotlib] Hunter J D 2007 Comput. Sci. Eng. vol9  p90–95 ISSN 1521-9615

.. [SciPy] Jones E, Oliphant T, Peterson P et al.
   2001– SciPy: Open source scientific tools for Python URL
   http://www.scipy.org/

.. [FFTw] Frigo M and Johnson S G
   2005 Proceedings of the IEEE 93 p 216–231

.. [LImA] The LIMA Project Update
   S. Petitdemange, L. Claustre, A. Homs, R. Homs Regojo, E. Papillon
   Proceedings of ICALEPCS2013
   http://accelconf.web.cern.ch/AccelConf/ICALEPCS2013/html/auth1084.htm

.. [PyOpenCL]  PyCUDA and PyOpenCL: A scripting-based approach to GPU run-time code generation
   Andreas Klöckner, Nicolas Pinto, Yunsup Lee, Bryan Catanzaro, Paul Ivanov, Ahmed Fasih,
   Parallel Computing Vol 38, 3, March 2012, Pages 157–174
   http://dx.doi.org/10.1016/j.parco.2011.09.001

.. [AMD] The American Mineralogist Crystal Structure Database.
   Downs, R.T. and Hall-Wallace, M. (2003)
   American Mineralogist 88, 247-250
   http://rruff.geo.arizona.edu/AMS/amcsd.php

.. [COD] Crystallography Open Database: an open-access collection of crystal structures and platform for world-wide collaboration
   Saulius Grazulis et al.
   Nucl. Acids Res. (2012) 40 (D1): D420-D427.
   http://dx.doi.org/10.1093/nar/gkr900
   http://www.crystallography.net/

.. [Dpdak] A customizable software for fast reduction and analysis of large X-ray scattering data sets: applications of the new DPDAK package to small angle X-ray scattering and grazing-incidence small angle X-ray scattering,
   Benecke, G. et al., (2014)
   J. Appl. Cryst. 47,
   http://dx.doi.org/10.1107/S1600576714019773

